#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_form.form import AJAXEditForm
from pyams_form.interfaces.form import IInnerTabForm
from pyams_pagelet.interfaces import IPagelet
from pyams_pagelet.pagelet import pagelet_config
from pyams_portal.interfaces import IPortletPreviewer
from pyams_portal.portlet import PortletPreviewer
from pyams_portal.portlets.spacer import ISpacerPortletSettings
from pyams_portal.zmi.portlet import PortletSettingsEditor, PortletSettingsPropertiesEditor
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION


#
# Spacer portlet properties
#

@pagelet_config(name='properties.html', context=ISpacerPortletSettings, request_type=IPyAMSLayer,
                permission=VIEW_SYSTEM_PERMISSION)
class SpacerPortletSettingsEditor(PortletSettingsEditor):
    """Spacer HTML portlet settings editor"""

    settings = ISpacerPortletSettings


@adapter_config(name='properties', context=(Interface, IPyAMSLayer, SpacerPortletSettingsEditor), provides=IInnerTabForm)
class SpacerPortletSettingsPropertiesEditor(PortletSettingsPropertiesEditor):
    """Spacer portlet settings properties editor"""


@adapter_config(name='properties.json', context=(ISpacerPortletSettings, IPyAMSLayer), provides=IPagelet)
class SpacerPortletConfigurationAJAXEditor(AJAXEditForm, SpacerPortletSettingsEditor):
    """Spacer portlet settings editor, AJAX renderer"""


@adapter_config(context=(Interface, IPyAMSLayer, Interface, ISpacerPortletSettings), provides=IPortletPreviewer)
@template_config(template='preview.pt', layer=IPyAMSLayer)
class SpacerPortletPreviewer(PortletPreviewer):
    """Spacer portlet previewer"""
